@@ -93,7 +93,7 @@ spscan.test <-
     N1 = length(idxcase)
     coords = matrix(c(x$x, x$y), ncol = 2)
 
-    d = sp::spDists(cbind(x$x, x$y), longlat = longlat)
+    d = smerc::gedist(cbind(x$x, x$y), longlat = longlat)
     
     if (is.null(maxd)) maxd = max(d)/2
     
@@ -235,7 +235,7 @@ spscan.test <-
     sig_p = pvalue[usigc]
     sig_coords = coords[usigc,, drop = FALSE]
     # sig_r = diag(SpatialTools::dist2(sig_coords, coords[max_nn[usigc], , drop = FALSE]))
-    sig_r = sp::spDists(sig_coords, coords[max_nn[usigc], , drop = FALSE], longlat = longlat, diagonal = TRUE)
+    sig_r = smerc::gedist(sig_coords, coords[max_nn[usigc], , drop = FALSE], longlat = longlat)#, diagonal = TRUE)
     sig_popin = (Nin[tmax_idx])[usigc]
     sig_yin = (N1in[tmax_idx])[usigc]
     sig_ein = (N1/N)*sig_popin
